@@ -565,6 +565,12 @@ void io_tty_process_input(uv_stream_t *stream, ssize_t nread, const uv_buf_t *bu
 		if (dup_fd >= 0) {
 			out = fdopen(dup_fd, "w");
 		}
+
+		if (!out) {
+			close(dup_fd);
+			/* fallback to standard output */
+			out = stdout;
+		}
 	}
 
 	/** The current single command and the remaining command(s). */
